@@ -1,6 +1,6 @@
 from PointSystem.Economy import item
 
-class points:
+class points():
     def __init__(self, tokenAmount: int, *,  classifier: str = None, front: bool = False):
         self.str = None
         self.points = tokenAmount
